@@ -18,6 +18,7 @@ from .._shared import MOBase
 from .._shared import OrgUnitRef
 from .._shared import PersonRef
 from .._shared import Validity
+from ._shared import Details
 
 # --------------------------------------------------------------------------------------
 # IT Systems
@@ -74,6 +75,10 @@ class ITUserWrite(ITUserBase):
     )
 
 
+class ITUserDetail(ITUserWrite, Details):
+    pass
+
+
 class ITUser(MOBase):
     type_: Literal["it"] = Field("it", alias="type", description="The object type.")
     user_key: str = Field(description="The IT user account name.")
